0.2.21 (2023-09-04)
-------------------

Make it possible to select a new theme on the website and store
the selection result in the session.

- Added a snippet viewset to be able to do CRUD on tags via wagtail admin #100
- Let users select a theme for the site and store the choice in the session #105
- Added a new api endpoint to get the list of available themes and update the selected theme #105
